import pyhausbus.HausBusUtils as HausBusUtils

class Off:
  CLASS_ID = 20
  FUNCTION_ID = 2

  def __init__(self,offDelay:int):
    self.offDelay=offDelay


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return Off(HausBusUtils.bytesToWord(dataIn, offset))

  def __str__(self):
    return f"Off(offDelay={self.offDelay})"

  '''
  @param offDelay Ausschaltverzoegerung: Wert * Zeitbasis [ms]\r\n0=Keine.
  '''
  def getOffDelay(self):
    return self.offDelay






import pyhausbus.HausBusUtils as HausBusUtils

class GetRemoteObjects:
  CLASS_ID = 0
  FUNCTION_ID = 3

  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return GetRemoteObjects()

  def __str__(self):
    return f"GetRemoteObjects()"






import pyhausbus.HausBusUtils as HausBusUtils
class MOptions:

  def setInvertDirection(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 0, self.value)
    return self;

  def isInvertDirection(self):
    return HausBusUtils.isBitSet(0, self.value)
  def setIndependent(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 1, self.value)
    return self;

  def isIndependent(self):
    return HausBusUtils.isBitSet(1, self.value)
  def setInvertOutputs(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 2, self.value)
    return self;

  def isInvertOutputs(self):
    return HausBusUtils.isBitSet(2, self.value)
  def setSoftStartDCMotor(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 3, self.value)
    return self;

  def isSoftStartDCMotor(self):
    return HausBusUtils.isBitSet(3, self.value)
  def setReserved1(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 4, self.value)
    return self;

  def isReserved1(self):
    return HausBusUtils.isBitSet(4, self.value)
  def setReserved2(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 5, self.value)
    return self;

  def isReserved2(self):
    return HausBusUtils.isBitSet(5, self.value)
  def setReserved3(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 6, self.value)
    return self;

  def isReserved3(self):
    return HausBusUtils.isBitSet(6, self.value)
  def setEnableTracing(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 7, self.value)
    return self;

  def isEnableTracing(self):
    return HausBusUtils.isBitSet(7, self.value)
  def __init__(self, value:int):
    self.value = value

  @staticmethod
  def _fromBytes(data:bytearray, offset):
    return MOptions(HausBusUtils.bytesToInt(data, offset))



  def getValue(self):
    return self.value
  def getEntryNames(self):
    result = []
    result.append("InvertDirection")
    result.append("Independent")
    result.append("InvertOutputs")
    result.append("SoftStartDCMotor")
    result.append("Reserved1")
    result.append("Reserved2")
    result.append("Reserved3")
    result.append("EnableTracing")
    return result
  def setEntry(self,name:str, setValue:bool):
    if (name == "InvertDirection"):
      self.setInvertDirection(setValue)
    if (name == "Independent"):
      self.setIndependent(setValue)
    if (name == "InvertOutputs"):
      self.setInvertOutputs(setValue)
    if (name == "SoftStartDCMotor"):
      self.setSoftStartDCMotor(setValue)
    if (name == "Reserved1"):
      self.setReserved1(setValue)
    if (name == "Reserved2"):
      self.setReserved2(setValue)
    if (name == "Reserved3"):
      self.setReserved3(setValue)
    if (name == "EnableTracing"):
      self.setEnableTracing(setValue)

  def __str__(self):
    return f"MOptions(InvertDirection = {self.isInvertDirection()}, Independent = {self.isIndependent()}, InvertOutputs = {self.isInvertOutputs()}, SoftStartDCMotor = {self.isSoftStartDCMotor()}, Reserved1 = {self.isReserved1()}, Reserved2 = {self.isReserved2()}, Reserved3 = {self.isReserved3()}, EnableTracing = {self.isEnableTracing()})"






import pyhausbus.HausBusUtils as HausBusUtils

class DecSignalCount:
  CLASS_ID = 90
  FUNCTION_ID = 10

  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return DecSignalCount()

  def __str__(self):
    return f"DecSignalCount()"






import pyhausbus.HausBusUtils as HausBusUtils

class UnusedMemory:
  CLASS_ID = 0
  FUNCTION_ID = 130

  def __init__(self,freeStack:int, freeHeap:int):
    self.freeStack=freeStack
    self.freeHeap=freeHeap


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return UnusedMemory(HausBusUtils.bytesToWord(dataIn, offset), HausBusUtils.bytesToWord(dataIn, offset))

  def __str__(self):
    return f"UnusedMemory(freeStack={self.freeStack}, freeHeap={self.freeHeap})"

  '''
  @param freeStack Anzahl des nicht genutzten Stacks in Bytes..
  '''
  def getFreeStack(self):
    return self.freeStack

  '''
  @param freeHeap Aktuell freier Heap in Bytes..
  '''
  def getFreeHeap(self):
    return self.freeHeap






from pyhausbus.de.hausbus.homeassistant.proxy.gateway.params.MOptions import MOptions
import pyhausbus.HausBusUtils as HausBusUtils

class SetConfiguration:
  CLASS_ID = 176
  FUNCTION_ID = 1

  def __init__(self,options:MOptions):
    self.options=options


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return SetConfiguration(MOptions._fromBytes(dataIn, offset))

  def __str__(self):
    return f"SetConfiguration(options={self.options})"

  '''
  @param options enabled: Dies Gateway ist aktiv und leitet Nachrichten weiter\r\npreferLoxone: Gateway kommuniziert bevorzugt im Loxone-Protokoll\r\nenableConsole: aktiviert das senden von Debugausgaben\r\nmaster: dieses Gateway soll das Bus-Timing verwalten\r\n\r\nReservierte Bits muessen immer deaktiviert sein. Das Aktivieren eines reservierten Bits fuehrt nach dem Neustart des Controllers zu den Standart-Einstellungen..
  '''
  def getOptions(self) -> MOptions:
    return self.options






import pyhausbus.HausBusUtils as HausBusUtils
from enum import Enum

class EErrorCode(Enum):
  OK=0
  START_FAIL=1
  FAILTURE=2
  OUT_OF_MEMORY=4
  RESULT_NOT_AVAILABLE=12
  CONFIGURATION_OUT_OF_MEMORY=128
  ANY_ERROR=255
  SER_UNKNOWN=-1

  @staticmethod
  def _fromBytes(data:bytearray, offset):
    checkValue = HausBusUtils.bytesToInt(data, offset)
    for act in EErrorCode.__members__.values():
      if (act.value == checkValue):
        return act

    return EErrorCode.SER_UNKNOWN

  @staticmethod
  def value_of(name: str) -> 'EErrorCode':
    try:
      return EErrorCode[name]
    except KeyError:
      return EErrorCode.SER_UNKNOWN 







import pyhausbus.HausBusUtils as HausBusUtils

class Time:
  CLASS_ID = 3
  FUNCTION_ID = 128

  def __init__(self,weekday:int, date:int, month:int, year:int, hours:int, minutes:int, seconds:int):
    self.weekday=weekday
    self.date=date
    self.month=month
    self.year=year
    self.hours=hours
    self.minutes=minutes
    self.seconds=seconds


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return Time(HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToWord(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"Time(weekday={self.weekday}, date={self.date}, month={self.month}, year={self.year}, hours={self.hours}, minutes={self.minutes}, seconds={self.seconds})"

  '''
  @param weekday .
  '''
  def getWeekday(self):
    return self.weekday

  '''
  @param date .
  '''
  def getDate(self):
    return self.date

  '''
  @param month .
  '''
  def getMonth(self):
    return self.month

  '''
  @param year .
  '''
  def getYear(self):
    return self.year

  '''
  @param hours .
  '''
  def getHours(self):
    return self.hours

  '''
  @param minutes .
  '''
  def getMinutes(self):
    return self.minutes

  '''
  @param seconds .
  '''
  def getSeconds(self):
    return self.seconds






import pyhausbus.HausBusUtils as HausBusUtils
from enum import Enum

class ENewState(Enum):
  NO_COMMAND=0
  START_MOTOR=1
  MOTOR_IS_RUNNING=2
  STOP_MOTOR=3
  NOTIFY_RUNNING=4
  NOTIFY_STOPPED=5
  SER_UNKNOWN=-1

  @staticmethod
  def _fromBytes(data:bytearray, offset):
    checkValue = HausBusUtils.bytesToInt(data, offset)
    for act in ENewState.__members__.values():
      if (act.value == checkValue):
        return act

    return ENewState.SER_UNKNOWN

  @staticmethod
  def value_of(name: str) -> 'ENewState':
    try:
      return ENewState[name]
    except KeyError:
      return ENewState.SER_UNKNOWN 







import pyhausbus.HausBusUtils as HausBusUtils

class EvOpen:
  CLASS_ID = 18
  FUNCTION_ID = 202

  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EvOpen()

  def __str__(self):
    return f"EvOpen()"






import pyhausbus.HausBusUtils as HausBusUtils

class Configuration:
  CLASS_ID = 22
  FUNCTION_ID = 128

  def __init__(self,fadingTime:int):
    self.fadingTime=fadingTime


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return Configuration(HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"Configuration(fadingTime={self.fadingTime})"

  '''
  @param fadingTime Zeit a 50ms um zwischen den unterschiedlichen Helligkeitsstufen zu schalten.
  '''
  def getFadingTime(self):
    return self.fadingTime






from pyhausbus.de.hausbus.homeassistant.proxy.controller.params.EFeatureId import EFeatureId
import pyhausbus.HausBusUtils as HausBusUtils

class EnableFeature:
  CLASS_ID = 0
  FUNCTION_ID = 19

  def __init__(self,featureId:EFeatureId, key:str):
    self.featureId=featureId
    self.key=key


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EnableFeature(EFeatureId._fromBytes(dataIn, offset), HausBusUtils.bytesToString(dataIn, offset))

  def __str__(self):
    return f"EnableFeature(featureId={self.featureId}, key={self.key})"

  '''
  @param featureId Zusatzfunktion.
  '''
  def getFeatureId(self):
    return self.featureId

  '''
  @param key Der Schluessel mit dem die Zusatzfunktion aktiviert werden soll..
  '''
  def getKey(self):
    return self.key






import pyhausbus.HausBusUtils as HausBusUtils

class TriggerRuleElement:
  CLASS_ID = 0
  FUNCTION_ID = 13

  def __init__(self,indexRule:int, indexElement:int):
    self.indexRule=indexRule
    self.indexElement=indexElement


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return TriggerRuleElement(HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"TriggerRuleElement(indexRule={self.indexRule}, indexElement={self.indexElement})"

  '''
  @param indexRule Index der Regel im Controller..
  '''
  def getIndexRule(self):
    return self.indexRule

  '''
  @param indexElement Index des auszufuehrenden Regelelementes. Alle Aktionen werden ausgefuehrt und der neue Zustand eingenommen..
  '''
  def getIndexElement(self):
    return self.indexElement






from pyhausbus.de.hausbus.homeassistant.proxy.currentReader.params.MConfig import MConfig
import pyhausbus.HausBusUtils as HausBusUtils

class EvDebug:
  CLASS_ID = 90
  FUNCTION_ID = 210

  def __init__(self,data:int, type:MConfig):
    self.data=data
    self.type=type


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EvDebug(HausBusUtils.bytesToDWord(dataIn, offset), MConfig._fromBytes(dataIn, offset))

  def __str__(self):
    return f"EvDebug(data={self.data}, type={self.type})"

  '''
  @param data .
  '''
  def getData(self):
    return self.data

  '''
  @param type .
  '''
  def getType(self) -> MConfig:
    return self.type






import pyhausbus.HausBusUtils as HausBusUtils
class MLogicalButtonMask:

  def setLogicalButton0(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 0, self.value)
    return self;

  def isLogicalButton0(self):
    return HausBusUtils.isBitSet(0, self.value)
  def setLogicalButton1(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 1, self.value)
    return self;

  def isLogicalButton1(self):
    return HausBusUtils.isBitSet(1, self.value)
  def setLogicalButton2(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 2, self.value)
    return self;

  def isLogicalButton2(self):
    return HausBusUtils.isBitSet(2, self.value)
  def setLogicalButton3(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 3, self.value)
    return self;

  def isLogicalButton3(self):
    return HausBusUtils.isBitSet(3, self.value)
  def setLogicalButton4(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 4, self.value)
    return self;

  def isLogicalButton4(self):
    return HausBusUtils.isBitSet(4, self.value)
  def setLogicalButton5(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 5, self.value)
    return self;

  def isLogicalButton5(self):
    return HausBusUtils.isBitSet(5, self.value)
  def setLogicalButton6(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 6, self.value)
    return self;

  def isLogicalButton6(self):
    return HausBusUtils.isBitSet(6, self.value)
  def setLogicalButton7(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 7, self.value)
    return self;

  def isLogicalButton7(self):
    return HausBusUtils.isBitSet(7, self.value)
  def __init__(self, value:int):
    self.value = value

  @staticmethod
  def _fromBytes(data:bytearray, offset):
    return MLogicalButtonMask(HausBusUtils.bytesToInt(data, offset))



  def getValue(self):
    return self.value
  def getEntryNames(self):
    result = []
    result.append("LogicalButton0")
    result.append("LogicalButton1")
    result.append("LogicalButton2")
    result.append("LogicalButton3")
    result.append("LogicalButton4")
    result.append("LogicalButton5")
    result.append("LogicalButton6")
    result.append("LogicalButton7")
    return result
  def setEntry(self,name:str, setValue:bool):
    if (name == "LogicalButton0"):
      self.setLogicalButton0(setValue)
    if (name == "LogicalButton1"):
      self.setLogicalButton1(setValue)
    if (name == "LogicalButton2"):
      self.setLogicalButton2(setValue)
    if (name == "LogicalButton3"):
      self.setLogicalButton3(setValue)
    if (name == "LogicalButton4"):
      self.setLogicalButton4(setValue)
    if (name == "LogicalButton5"):
      self.setLogicalButton5(setValue)
    if (name == "LogicalButton6"):
      self.setLogicalButton6(setValue)
    if (name == "LogicalButton7"):
      self.setLogicalButton7(setValue)

  def __str__(self):
    return f"MLogicalButtonMask(LogicalButton0 = {self.isLogicalButton0()}, LogicalButton1 = {self.isLogicalButton1()}, LogicalButton2 = {self.isLogicalButton2()}, LogicalButton3 = {self.isLogicalButton3()}, LogicalButton4 = {self.isLogicalButton4()}, LogicalButton5 = {self.isLogicalButton5()}, LogicalButton6 = {self.isLogicalButton6()}, LogicalButton7 = {self.isLogicalButton7()})"






import pyhausbus.HausBusUtils as HausBusUtils

class Power:
  CLASS_ID = 90
  FUNCTION_ID = 130

  def __init__(self,power:int):
    self.power=power


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return Power(HausBusUtils.bytesToWord(dataIn, offset))

  def __str__(self):
    return f"Power(power={self.power})"

  '''
  @param power Aktuelle Leistung in Watt.
  '''
  def getPower(self):
    return self.power






from pyhausbus.HausBusUtils import LOGGER
import time
import threading


class ResultWorker:
  _instance = None
  _resultClass = None
  _resultSenderObjectId = 0
  _resultObject = None
  _condition = threading.Condition()

  def __new__(cls, *args, **kwargs):
    if not cls._instance:
      cls._instance = super().__new__(cls, *args, **kwargs)
    return cls._instance

  def _setResultInfo(self, resultClass, resultSenderObjectId:int):
    '''print("resultInfo " + str(resultClass) + ", ID " + str(resultSenderObjectId))'''
    self._resultClass = resultClass
    self._resultSenderObjectId = resultSenderObjectId
    self._resultObject=None

  def waitForResult(self, timeoutInSeconds:int):
    start_time = time.time()
    end_time = start_time + timeoutInSeconds

    with self._condition:
      while self._resultObject == None and time.time() < end_time:
        self._condition.wait(1)

    return self._resultObject

  def waitForEvent(self, event, eventSenderObjectId, timeoutInSeconds:int):
    self._resultClass = event
    self._resultSenderObjectId = eventSenderObjectId
    self._resultObject=None

    start_time = time.time()
    end_time = start_time + timeoutInSeconds

    with self._condition:
      while self._resultObject == None and time.time() < end_time:
        self._condition.wait(1)

    return self._resultObject

  def busDataReceived(self, busDataMessage):
    '''print("got "+str(busDataMessage))'''
    if (self._resultClass != None and busDataMessage.getSenderObjectId()==self._resultSenderObjectId and isinstance(busDataMessage.getData(), self._resultClass)):
      with self._condition:
        self._resultObject = busDataMessage.getData()
        self._condition.notify()



import pyhausbus.HausBusUtils as HausBusUtils

class SendCommand:
  CLASS_ID = 160
  FUNCTION_ID = 4

  def __init__(self,command:int, address:int):
    self.command=command
    self.address=address


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return SendCommand(HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"SendCommand(command={self.command}, address={self.address})"

  '''
  @param command Dali Kommando s.Spezifikation.
  '''
  def getCommand(self):
    return self.command

  '''
  @param address Kurz- oder Gruppenadresse YAAA AAAS\r\n64 Kurzadressen           0AAA AAAS\r\n16 Gruppenadressen        100A AAAS\r\nSammelaufruf              1111 111S\r\n\r\nY: Adressenart: Y=?  ? ? ??  ?? ??? ??  ?0?  ? ? ??  ?? ??? ??  ? ? Kurzadresse.
  '''
  def getAddress(self):
    return self.address






import pyhausbus.HausBusUtils as HausBusUtils

class SetTargetValue:
  CLASS_ID = 44
  FUNCTION_ID = 2

  def __init__(self,targetValue:int):
    self.targetValue=targetValue


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return SetTargetValue(HausBusUtils.bytesToWord(dataIn, offset))

  def __str__(self):
    return f"SetTargetValue(targetValue={self.targetValue})"

  '''
  @param targetValue Regelungszielwert z.B. targetValue*0.
  '''
  def getTargetValue(self):
    return self.targetValue






from pyhausbus.de.hausbus.homeassistant.proxy.rollladen.params.MOptions import MOptions
import pyhausbus.HausBusUtils as HausBusUtils

class SetConfiguration:
  CLASS_ID = 18
  FUNCTION_ID = 1

  def __init__(self,closeTime:int, openTime:int, options:MOptions):
    self.closeTime=closeTime
    self.openTime=openTime
    self.options=options


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return SetConfiguration(HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), MOptions._fromBytes(dataIn, offset))

  def __str__(self):
    return f"SetConfiguration(closeTime={self.closeTime}, openTime={self.openTime}, options={self.options})"

  '''
  @param closeTime Zeit.
  '''
  def getCloseTime(self):
    return self.closeTime

  '''
  @param openTime Zeit.
  '''
  def getOpenTime(self):
    return self.openTime

  '''
  @param options invertDirection: invertiert die Richtung der Ansteuerung des Rollladen.\r\nindependent: behandelt die Relais unabhaengig voneinander d.h. pro Richtung wird nur das jeweilige Relais geschaltet\r\ninvertOutputs: steuert die angeschlossenen Relais mit activLow Logik\r\nenableTracing: Objekt sendet zus?tzliche Events f?r eine Fehlersuche.
  '''
  def getOptions(self) -> MOptions:
    return self.options






import pyhausbus.HausBusUtils as HausBusUtils

class TriggeredRule:
  CLASS_ID = 0
  FUNCTION_ID = 136

  def __init__(self,ruleIndex:int, elementIndex:int):
    self.ruleIndex=ruleIndex
    self.elementIndex=elementIndex


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return TriggeredRule(HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"TriggeredRule(ruleIndex={self.ruleIndex}, elementIndex={self.elementIndex})"

  '''
  @param ruleIndex .
  '''
  def getRuleIndex(self):
    return self.ruleIndex

  '''
  @param elementIndex .
  '''
  def getElementIndex(self):
    return self.elementIndex






from pyhausbus.HausBusCommand import HausBusCommand
from pyhausbus.ABusFeature import *
from pyhausbus.ResultWorker import ResultWorker
import pyhausbus.HausBusUtils as HausBusUtils
from pyhausbus.de.hausbus.homeassistant.proxy.dimmer.params.EMode import EMode
from pyhausbus.de.hausbus.homeassistant.proxy.dimmer.data.Configuration import Configuration
from pyhausbus.de.hausbus.homeassistant.proxy.dimmer.params.EDirection import EDirection
from pyhausbus.de.hausbus.homeassistant.proxy.dimmer.data.Status import Status
from pyhausbus.de.hausbus.homeassistant.proxy.dimmer.params.EErrorCode import EErrorCode

class Dimmer(ABusFeature):
  CLASS_ID:int = 17

  def __init__ (self,objectId:int):
    super().__init__(objectId)

  @staticmethod
  def create(deviceId:int, instanceId:int):
    return Dimmer(HausBusUtils.getObjectId(deviceId, 17, instanceId))

  """
  @param brightness aktuelle Helligkeit 0-100%.
  @param duration Einschaltdauer: Wert in Sekunden\r\n0=Endlos.
  """
  def evOn(self, brightness:int, duration:int):
    LOGGER.debug("evOn"+" brightness = "+str(brightness)+" duration = "+str(duration))
    hbCommand = HausBusCommand(self.objectId, 201, "evOn")
    hbCommand.addByte(brightness)
    hbCommand.addWord(duration)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param mode DIMM_CR: dieser Mode ist zu Verwenden.
  @param fadingTime Zeit a 50ms um 0-100% zu dimmen.
  @param dimmingTime Zeit a 50ms um 0-100% zu dimmen.
  @param dimmingRangeStart Startwert des Helligkeitbereiches in dem gedimmt werden soll. 0-100%.
  @param dimmingRangeEnd Endwert des Helligkeitbereiches in dem gedimmt werden soll. 0-100%.
  """
  def setConfiguration(self, mode:EMode, fadingTime:int, dimmingTime:int, dimmingRangeStart:int, dimmingRangeEnd:int):
    LOGGER.debug("setConfiguration"+" mode = "+str(mode)+" fadingTime = "+str(fadingTime)+" dimmingTime = "+str(dimmingTime)+" dimmingRangeStart = "+str(dimmingRangeStart)+" dimmingRangeEnd = "+str(dimmingRangeEnd))
    hbCommand = HausBusCommand(self.objectId, 1, "setConfiguration")
    hbCommand.addByte(mode.value)
    hbCommand.addByte(fadingTime)
    hbCommand.addByte(dimmingTime)
    hbCommand.addByte(dimmingRangeStart)
    hbCommand.addByte(dimmingRangeEnd)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def getConfiguration(self):
    LOGGER.debug("getConfiguration")
    hbCommand = HausBusCommand(self.objectId, 0, "getConfiguration")
    ResultWorker()._setResultInfo(Configuration,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param brightness Helligkeit in Prozent.
  @param duration Einschaltdauer in Sekunden.
  """
  def setBrightness(self, brightness:int, duration:int):
    LOGGER.debug("setBrightness"+" brightness = "+str(brightness)+" duration = "+str(duration))
    hbCommand = HausBusCommand(self.objectId, 2, "setBrightness")
    hbCommand.addByte(brightness)
    hbCommand.addWord(duration)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param mode DIMM_CR: Dimmer arbeitet mit Phasenabschnitt\r\nDIMM_L: Dimmer arbeitet mit Phasenanschnitt\r\nSWITCH: Dimmer schaltet nur keine Dimmfunktion\r\n\r\nACHTUNG: EIN FALSCHER MODE.
  @param fadingTime Zeit a 50ms um zwischen den unterschiedlichen Helligkeitsstufen zu schalten.
  @param dimmingTime Zeit a 50ms um zwischen den unterschiedlichen Helligkeitsstufen zu dimmen.
  @param dimmingRangeStart Startwert des Helligkeitbereiches in dem gedimmt werden soll. 0-100%.
  @param dimmingRangeEnd Endwert des Helligkeitbereiches in dem gedimmt werden soll. 0-100%.
  """
  def Configuration(self, mode:EMode, fadingTime:int, dimmingTime:int, dimmingRangeStart:int, dimmingRangeEnd:int):
    LOGGER.debug("Configuration"+" mode = "+str(mode)+" fadingTime = "+str(fadingTime)+" dimmingTime = "+str(dimmingTime)+" dimmingRangeStart = "+str(dimmingRangeStart)+" dimmingRangeEnd = "+str(dimmingRangeEnd))
    hbCommand = HausBusCommand(self.objectId, 128, "Configuration")
    hbCommand.addByte(mode.value)
    hbCommand.addByte(fadingTime)
    hbCommand.addByte(dimmingTime)
    hbCommand.addByte(dimmingRangeStart)
    hbCommand.addByte(dimmingRangeEnd)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def evOff(self):
    LOGGER.debug("evOff")
    hbCommand = HausBusCommand(self.objectId, 200, "evOff")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param direction .
  """
  def evStart(self, direction:EDirection):
    LOGGER.debug("evStart"+" direction = "+str(direction))
    hbCommand = HausBusCommand(self.objectId, 202, "evStart")
    hbCommand.addByte(direction.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param direction .
  """
  def start(self, direction:EDirection):
    LOGGER.debug("start"+" direction = "+str(direction))
    hbCommand = HausBusCommand(self.objectId, 3, "start")
    hbCommand.addByte(direction.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def stop(self):
    LOGGER.debug("stop")
    hbCommand = HausBusCommand(self.objectId, 4, "stop")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def getStatus(self):
    LOGGER.debug("getStatus")
    hbCommand = HausBusCommand(self.objectId, 5, "getStatus")
    ResultWorker()._setResultInfo(Status,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param brightness aktuelle Helligkeit 0-100%.
  @param duration Einschaltdauer: Wert in Sekunden\r\n0=Endlos.
  """
  def Status(self, brightness:int, duration:int):
    LOGGER.debug("Status"+" brightness = "+str(brightness)+" duration = "+str(duration))
    hbCommand = HausBusCommand(self.objectId, 129, "Status")
    hbCommand.addByte(brightness)
    hbCommand.addWord(duration)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param errorCode NO_ZERO_CROSS_DETECTED: Nulldurchgaenge koennen nicht detektiert werde.
  """
  def evError(self, errorCode:EErrorCode):
    LOGGER.debug("evError"+" errorCode = "+str(errorCode))
    hbCommand = HausBusCommand(self.objectId, 255, "evError")
    hbCommand.addByte(errorCode.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")





import pyhausbus.HausBusUtils as HausBusUtils

class Configuration:
  CLASS_ID = 43
  FUNCTION_ID = 128

  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return Configuration()

  def __str__(self):
    return f"Configuration()"






import pyhausbus.HausBusUtils as HausBusUtils

class SetConfiguration:
  CLASS_ID = 164
  FUNCTION_ID = 1

  def __init__(self,SSID:str, Password:str, Server_Port:int, Server_IP0:int, Server_IP1:int, Server_IP2:int, Server_IP3:int):
    self.SSID=SSID
    self.Password=Password
    self.Server_Port=Server_Port
    self.Server_IP0=Server_IP0
    self.Server_IP1=Server_IP1
    self.Server_IP2=Server_IP2
    self.Server_IP3=Server_IP3


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return SetConfiguration(HausBusUtils.bytesToString(dataIn, offset), HausBusUtils.bytesToString(dataIn, offset), HausBusUtils.bytesToWord(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"SetConfiguration(SSID={self.SSID}, Password={self.Password}, Server_Port={self.Server_Port}, Server_IP0={self.Server_IP0}, Server_IP1={self.Server_IP1}, Server_IP2={self.Server_IP2}, Server_IP3={self.Server_IP3})"

  '''
  @param SSID .
  '''
  def getSSID(self):
    return self.SSID

  '''
  @param Password .
  '''
  def getPassword(self):
    return self.Password

  '''
  @param Server_Port Zusaetzlicher Port fuer die Homeserverfunktionen z.B 15557 fuer Loxone oder 5855 f?r IOBroker.
  '''
  def getServer_Port(self):
    return self.Server_Port

  '''
  @param Server_IP0 Server IP-Adresse im Format IP0.IP1.IP2.IP3 0.0.0.0 deaktiviert das Gateway 13 und 14.
  '''
  def getServer_IP0(self):
    return self.Server_IP0

  '''
  @param Server_IP1 Server IP-Adresse im Format IP0.IP1.IP2.IP3 0.0.0.0 deaktiviert das Gateway 13 und 14.
  '''
  def getServer_IP1(self):
    return self.Server_IP1

  '''
  @param Server_IP2 Server IP-Adresse im Format IP0.IP1.IP2.IP3 0.0.0.0 deaktiviert das Gateway 13 und 14.
  '''
  def getServer_IP2(self):
    return self.Server_IP2

  '''
  @param Server_IP3 Server IP-Adresse im Format IP0.IP1.IP2.IP3 0.0.0.0 deaktiviert das Gateway 13 und 14.
  '''
  def getServer_IP3(self):
    return self.Server_IP3






import pyhausbus.HausBusUtils as HausBusUtils

class Configuration:
  CLASS_ID = 39
  FUNCTION_ID = 128

  def __init__(self,lowerThreshold:int, upperThreshold:int, reportTimeBase:int, minReportTime:int, maxReportTime:int, hysteresis:int, calibration:int, deltaSensorID:int):
    self.lowerThreshold=lowerThreshold
    self.upperThreshold=upperThreshold
    self.reportTimeBase=reportTimeBase
    self.minReportTime=minReportTime
    self.maxReportTime=maxReportTime
    self.hysteresis=hysteresis
    self.calibration=calibration
    self.deltaSensorID=deltaSensorID


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return Configuration(HausBusUtils.bytesToWord(dataIn, offset), HausBusUtils.bytesToWord(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToSInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"Configuration(lowerThreshold={self.lowerThreshold}, upperThreshold={self.upperThreshold}, reportTimeBase={self.reportTimeBase}, minReportTime={self.minReportTime}, maxReportTime={self.maxReportTime}, hysteresis={self.hysteresis}, calibration={self.calibration}, deltaSensorID={self.deltaSensorID})"

  '''
  @param lowerThreshold untere Helligkeitsschwelle.
  '''
  def getLowerThreshold(self):
    return self.lowerThreshold

  '''
  @param upperThreshold obere Helligkeitsschwelle.
  '''
  def getUpperThreshold(self):
    return self.upperThreshold

  '''
  @param reportTimeBase Zeitbasis fuer die Einstellungen von minReportTime und maxReportTime.
  '''
  def getReportTimeBase(self):
    return self.reportTimeBase

  '''
  @param minReportTime Mindestzeit.
  '''
  def getMinReportTime(self):
    return self.minReportTime

  '''
  @param maxReportTime Maximalzeit.
  '''
  def getMaxReportTime(self):
    return self.maxReportTime

  '''
  @param hysteresis Hysterese [10 lux].
  '''
  def getHysteresis(self):
    return self.hysteresis

  '''
  @param calibration Dieser Wert wird verwendet um die vom Sensor gelieferten Messwerte zu justieren. [10 lux].
  '''
  def getCalibration(self):
    return self.calibration

  '''
  @param deltaSensorID Die InstanceID des Sensors auf diesem Controller.
  '''
  def getDeltaSensorID(self):
    return self.deltaSensorID






from pyhausbus.HausBusCommand import HausBusCommand
from pyhausbus.ABusFeature import *
from pyhausbus.ResultWorker import ResultWorker
import pyhausbus.HausBusUtils as HausBusUtils
from pyhausbus.de.hausbus.homeassistant.proxy.systemTime.data.Time import Time
from pyhausbus.de.hausbus.homeassistant.proxy.systemTime.params.EWeekDay import EWeekDay
from pyhausbus.de.hausbus.homeassistant.proxy.systemTime.params.EDate import EDate
from pyhausbus.de.hausbus.homeassistant.proxy.systemTime.params.EMonth import EMonth
from pyhausbus.de.hausbus.homeassistant.proxy.systemTime.params.EErrorCode import EErrorCode

class SystemTime(ABusFeature):
  CLASS_ID:int = 3

  def __init__ (self,objectId:int):
    super().__init__(objectId)

  @staticmethod
  def create(deviceId:int, instanceId:int):
    return SystemTime(HausBusUtils.getObjectId(deviceId, 3, instanceId))

  """
  """
  def getTime(self):
    LOGGER.debug("getTime")
    hbCommand = HausBusCommand(self.objectId, 0, "getTime")
    ResultWorker()._setResultInfo(Time,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param weekDay .
  @param date .
  @param month .
  @param year .
  @param hours .
  @param minutes .
  @param seconds .
  """
  def setTime(self, weekDay:EWeekDay, date:EDate, month:EMonth, year:int, hours:int, minutes:int, seconds:int):
    LOGGER.debug("setTime"+" weekDay = "+str(weekDay)+" date = "+str(date)+" month = "+str(month)+" year = "+str(year)+" hours = "+str(hours)+" minutes = "+str(minutes)+" seconds = "+str(seconds))
    hbCommand = HausBusCommand(self.objectId, 1, "setTime")
    hbCommand.addByte(weekDay.value)
    hbCommand.addByte(date.value)
    hbCommand.addByte(month.value)
    hbCommand.addWord(year)
    hbCommand.addByte(hours)
    hbCommand.addByte(minutes)
    hbCommand.addByte(seconds)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param weekday .
  @param date .
  @param month .
  @param year .
  @param hours .
  @param minutes .
  @param seconds .
  """
  def Time(self, weekday:int, date:int, month:int, year:int, hours:int, minutes:int, seconds:int):
    LOGGER.debug("Time"+" weekday = "+str(weekday)+" date = "+str(date)+" month = "+str(month)+" year = "+str(year)+" hours = "+str(hours)+" minutes = "+str(minutes)+" seconds = "+str(seconds))
    hbCommand = HausBusCommand(self.objectId, 128, "Time")
    hbCommand.addByte(weekday)
    hbCommand.addByte(date)
    hbCommand.addByte(month)
    hbCommand.addWord(year)
    hbCommand.addByte(hours)
    hbCommand.addByte(minutes)
    hbCommand.addByte(seconds)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param errorCode .
  """
  def evError(self, errorCode:EErrorCode):
    LOGGER.debug("evError"+" errorCode = "+str(errorCode))
    hbCommand = HausBusCommand(self.objectId, 255, "evError")
    hbCommand.addByte(errorCode.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")





from pyhausbus.HausBusCommand import HausBusCommand
from pyhausbus.ABusFeature import *
from pyhausbus.ResultWorker import ResultWorker
import pyhausbus.HausBusUtils as HausBusUtils
from pyhausbus.de.hausbus.homeassistant.proxy.rollladen.data.Configuration import Configuration
from pyhausbus.de.hausbus.homeassistant.proxy.rollladen.params.EDirection import EDirection
from pyhausbus.de.hausbus.homeassistant.proxy.rollladen.params.MOptions import MOptions
from pyhausbus.de.hausbus.homeassistant.proxy.rollladen.data.Status import Status
from pyhausbus.de.hausbus.homeassistant.proxy.rollladen.params.EErrorCode import EErrorCode
from pyhausbus.de.hausbus.homeassistant.proxy.rollladen.params.ENewState import ENewState

class Rollladen(ABusFeature):
  CLASS_ID:int = 18

  def __init__ (self,objectId:int):
    super().__init__(objectId)

  @staticmethod
  def create(deviceId:int, instanceId:int):
    return Rollladen(HausBusUtils.getObjectId(deviceId, 18, instanceId))

  """
  """
  def getConfiguration(self):
    LOGGER.debug("getConfiguration")
    hbCommand = HausBusCommand(self.objectId, 0, "getConfiguration")
    ResultWorker()._setResultInfo(Configuration,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param position in Prozent.
  """
  def moveToPosition(self, position:int):
    LOGGER.debug("moveToPosition"+" position = "+str(position))
    hbCommand = HausBusCommand(self.objectId, 2, "moveToPosition")
    hbCommand.addByte(position)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param direction .
  """
  def start(self, direction:EDirection):
    LOGGER.debug("start"+" direction = "+str(direction))
    hbCommand = HausBusCommand(self.objectId, 3, "start")
    hbCommand.addByte(direction.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def stop(self):
    LOGGER.debug("stop")
    hbCommand = HausBusCommand(self.objectId, 4, "stop")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param closeTime Zeit.
  @param openTime Zeit.
  @param options invertDirection: invertiert die Richtung der Ansteuerung des Rollladen.\r\nindependent: behandelt die Relais unabhaengig voneinander d.h. pro Richtung wird nur das jeweilige Relais geschaltet\r\ninvertOutputs: steuert die angeschlossenen Relais mit activLow Logik\r\nenableTracing: Objekt sendet zus?tzliche Events f?r eine Fehlersuche.
  """
  def Configuration(self, closeTime:int, openTime:int, options:MOptions):
    LOGGER.debug("Configuration"+" closeTime = "+str(closeTime)+" openTime = "+str(openTime)+" options = "+str(options))
    hbCommand = HausBusCommand(self.objectId, 128, "Configuration")
    hbCommand.addByte(closeTime)
    hbCommand.addByte(openTime)
    hbCommand.addByte(options.getValue())
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param position in Prozent.
  """
  def evClosed(self, position:int):
    LOGGER.debug("evClosed"+" position = "+str(position))
    hbCommand = HausBusCommand(self.objectId, 200, "evClosed")
    hbCommand.addByte(position)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param direction .
  """
  def evStart(self, direction:EDirection):
    LOGGER.debug("evStart"+" direction = "+str(direction))
    hbCommand = HausBusCommand(self.objectId, 201, "evStart")
    hbCommand.addByte(direction.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def getStatus(self):
    LOGGER.debug("getStatus")
    hbCommand = HausBusCommand(self.objectId, 5, "getStatus")
    ResultWorker()._setResultInfo(Status,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param position .
  """
  def Status(self, position:int):
    LOGGER.debug("Status"+" position = "+str(position))
    hbCommand = HausBusCommand(self.objectId, 129, "Status")
    hbCommand.addByte(position)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param closeTime Zeit.
  @param openTime Zeit.
  @param options invertDirection: invertiert die Richtung der Ansteuerung des Rollladen.\r\nindependent: behandelt die Relais unabhaengig voneinander d.h. pro Richtung wird nur das jeweilige Relais geschaltet\r\ninvertOutputs: steuert die angeschlossenen Relais mit activLow Logik\r\nenableTracing: Objekt sendet zus?tzliche Events f?r eine Fehlersuche.
  """
  def setConfiguration(self, closeTime:int, openTime:int, options:MOptions):
    LOGGER.debug("setConfiguration"+" closeTime = "+str(closeTime)+" openTime = "+str(openTime)+" options = "+str(options))
    hbCommand = HausBusCommand(self.objectId, 1, "setConfiguration")
    hbCommand.addByte(closeTime)
    hbCommand.addByte(openTime)
    hbCommand.addByte(options.getValue())
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param errorCode .
  """
  def evError(self, errorCode:EErrorCode):
    LOGGER.debug("evError"+" errorCode = "+str(errorCode))
    hbCommand = HausBusCommand(self.objectId, 255, "evError")
    hbCommand.addByte(errorCode.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param position Aktuelle Position setzen 0-100% geschlossen.
  """
  def setPosition(self, position:int):
    LOGGER.debug("setPosition"+" position = "+str(position))
    hbCommand = HausBusCommand(self.objectId, 6, "setPosition")
    hbCommand.addByte(position)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def evOpen(self):
    LOGGER.debug("evOpen")
    hbCommand = HausBusCommand(self.objectId, 202, "evOpen")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param newState State.
  @param preState State.
  """
  def evNewMainState(self, newState:ENewState, preState:ENewState):
    LOGGER.debug("evNewMainState"+" newState = "+str(newState)+" preState = "+str(preState))
    hbCommand = HausBusCommand(self.objectId, 251, "evNewMainState")
    hbCommand.addByte(newState.value)
    hbCommand.addByte(preState.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param newState State.
  @param preState State.
  """
  def evNewSubState(self, newState:ENewState, preState:ENewState):
    LOGGER.debug("evNewSubState"+" newState = "+str(newState)+" preState = "+str(preState))
    hbCommand = HausBusCommand(self.objectId, 252, "evNewSubState")
    hbCommand.addByte(newState.value)
    hbCommand.addByte(preState.value)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")





from pyhausbus.de.hausbus.homeassistant.proxy.controller.params.EStatus import EStatus
import pyhausbus.HausBusUtils as HausBusUtils

class MemoryStatus:
  CLASS_ID = 0
  FUNCTION_ID = 133

  def __init__(self,status:EStatus, address:int):
    self.status=status
    self.address=address


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return MemoryStatus(EStatus._fromBytes(dataIn, offset), HausBusUtils.bytesToDWord(dataIn, offset))

  def __str__(self):
    return f"MemoryStatus(status={self.status}, address={self.address})"

  '''
  @param status Status des letzten Speicherzugriffs.
  '''
  def getStatus(self):
    return self.status

  '''
  @param address Speicheradresse zu dem dieser Status gesendet wird..
  '''
  def getAddress(self):
    return self.address






import pyhausbus.HausBusUtils as HausBusUtils
class MOption:

  def setSEND_TRIGGERED_RULE_EVENT(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 0, self.value)
    return self;

  def isSEND_TRIGGERED_RULE_EVENT(self):
    return HausBusUtils.isBitSet(0, self.value)
  def setREAD_ONLY_GATEWAYS(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 1, self.value)
    return self;

  def isREAD_ONLY_GATEWAYS(self):
    return HausBusUtils.isBitSet(1, self.value)
  def setREPORT_GATEWAY_LOAD(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 2, self.value)
    return self;

  def isREPORT_GATEWAY_LOAD(self):
    return HausBusUtils.isBitSet(2, self.value)
  def setREPORT_INTERNAL_TEMPERATURE(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 3, self.value)
    return self;

  def isREPORT_INTERNAL_TEMPERATURE(self):
    return HausBusUtils.isBitSet(3, self.value)
  def setSEND_ZERO_CROSS_DATA(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 4, self.value)
    return self;

  def isSEND_ZERO_CROSS_DATA(self):
    return HausBusUtils.isBitSet(4, self.value)
  def setReserved1(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 5, self.value)
    return self;

  def isReserved1(self):
    return HausBusUtils.isBitSet(5, self.value)
  def setReserved2(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 6, self.value)
    return self;

  def isReserved2(self):
    return HausBusUtils.isBitSet(6, self.value)
  def setReserved3(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 7, self.value)
    return self;

  def isReserved3(self):
    return HausBusUtils.isBitSet(7, self.value)
  def __init__(self, value:int):
    self.value = value

  @staticmethod
  def _fromBytes(data:bytearray, offset):
    return MOption(HausBusUtils.bytesToInt(data, offset))



  def getValue(self):
    return self.value
  def getEntryNames(self):
    result = []
    result.append("SEND_TRIGGERED_RULE_EVENT")
    result.append("READ_ONLY_GATEWAYS")
    result.append("REPORT_GATEWAY_LOAD")
    result.append("REPORT_INTERNAL_TEMPERATURE")
    result.append("SEND_ZERO_CROSS_DATA")
    result.append("Reserved1")
    result.append("Reserved2")
    result.append("Reserved3")
    return result
  def setEntry(self,name:str, setValue:bool):
    if (name == "SEND_TRIGGERED_RULE_EVENT"):
      self.setSEND_TRIGGERED_RULE_EVENT(setValue)
    if (name == "READ_ONLY_GATEWAYS"):
      self.setREAD_ONLY_GATEWAYS(setValue)
    if (name == "REPORT_GATEWAY_LOAD"):
      self.setREPORT_GATEWAY_LOAD(setValue)
    if (name == "REPORT_INTERNAL_TEMPERATURE"):
      self.setREPORT_INTERNAL_TEMPERATURE(setValue)
    if (name == "SEND_ZERO_CROSS_DATA"):
      self.setSEND_ZERO_CROSS_DATA(setValue)
    if (name == "Reserved1"):
      self.setReserved1(setValue)
    if (name == "Reserved2"):
      self.setReserved2(setValue)
    if (name == "Reserved3"):
      self.setReserved3(setValue)

  def __str__(self):
    return f"MOption(SEND_TRIGGERED_RULE_EVENT = {self.isSEND_TRIGGERED_RULE_EVENT()}, READ_ONLY_GATEWAYS = {self.isREAD_ONLY_GATEWAYS()}, REPORT_GATEWAY_LOAD = {self.isREPORT_GATEWAY_LOAD()}, REPORT_INTERNAL_TEMPERATURE = {self.isREPORT_INTERNAL_TEMPERATURE()}, SEND_ZERO_CROSS_DATA = {self.isSEND_ZERO_CROSS_DATA()}, Reserved1 = {self.isReserved1()}, Reserved2 = {self.isReserved2()}, Reserved3 = {self.isReserved3()})"






import pyhausbus.HausBusUtils as HausBusUtils

class EvHigh:
  CLASS_ID = 49
  FUNCTION_ID = 202

  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EvHigh()

  def __str__(self):
    return f"EvHigh()"






import pyhausbus.HausBusUtils as HausBusUtils

class EvGatewayLoad:
  CLASS_ID = 176
  FUNCTION_ID = 200

  def __init__(self,inMessagesPerMinute:int, outMessagesPerMinute:int, inBytesPerMinute:int, outBytesPerMinute:int, messageQueueHighWater:int):
    self.inMessagesPerMinute=inMessagesPerMinute
    self.outMessagesPerMinute=outMessagesPerMinute
    self.inBytesPerMinute=inBytesPerMinute
    self.outBytesPerMinute=outBytesPerMinute
    self.messageQueueHighWater=messageQueueHighWater


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EvGatewayLoad(HausBusUtils.bytesToWord(dataIn, offset), HausBusUtils.bytesToWord(dataIn, offset), HausBusUtils.bytesToDWord(dataIn, offset), HausBusUtils.bytesToDWord(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"EvGatewayLoad(inMessagesPerMinute={self.inMessagesPerMinute}, outMessagesPerMinute={self.outMessagesPerMinute}, inBytesPerMinute={self.inBytesPerMinute}, outBytesPerMinute={self.outBytesPerMinute}, messageQueueHighWater={self.messageQueueHighWater})"

  '''
  @param inMessagesPerMinute Anzahl der eingehenden Nachrichten pro Minute.
  '''
  def getInMessagesPerMinute(self):
    return self.inMessagesPerMinute

  '''
  @param outMessagesPerMinute Anzahl der ausgehenden Nachrichten pro Minute.
  '''
  def getOutMessagesPerMinute(self):
    return self.outMessagesPerMinute

  '''
  @param inBytesPerMinute Anzahl der Datenbytes von eingehenden Nachrichten pro Minute.
  '''
  def getInBytesPerMinute(self):
    return self.inBytesPerMinute

  '''
  @param outBytesPerMinute Anzahl der Datenbytes von ausgehenden Nachrichten pro Minute.
  '''
  def getOutBytesPerMinute(self):
    return self.outBytesPerMinute

  '''
  @param messageQueueHighWater Maximale Anzahl von Nachrichten in der Warteschlange innerhalb der letzten Minute.
  '''
  def getMessageQueueHighWater(self):
    return self.messageQueueHighWater






from pyhausbus.de.hausbus.homeassistant.proxy.pT1000.params.EErrorCode import EErrorCode
import pyhausbus.HausBusUtils as HausBusUtils

class EvError:
  CLASS_ID = 49
  FUNCTION_ID = 255

  def __init__(self,errorCode:EErrorCode):
    self.errorCode=errorCode


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EvError(EErrorCode._fromBytes(dataIn, offset))

  def __str__(self):
    return f"EvError(errorCode={self.errorCode})"

  '''
  @param errorCode .
  '''
  def getErrorCode(self):
    return self.errorCode






import pyhausbus.HausBusUtils as HausBusUtils
from enum import Enum

class ESlotType(Enum):
  UNUSED=0
  DIMMER=1
  SOCKET=2
  SHUTTER=3
  DOUBLE_SWITCH=7
  SOFT_START_SWITCH=8
  DIMMER_V30=10
  DIMMER_V31=11
  SER_UNKNOWN=-1

  @staticmethod
  def _fromBytes(data:bytearray, offset):
    checkValue = HausBusUtils.bytesToInt(data, offset)
    for act in ESlotType.__members__.values():
      if (act.value == checkValue):
        return act

    return ESlotType.SER_UNKNOWN

  @staticmethod
  def value_of(name: str) -> 'ESlotType':
    try:
      return ESlotType[name]
    except KeyError:
      return ESlotType.SER_UNKNOWN 







from pyhausbus.BusHandler import BusHandler
from pyhausbus.Templates import Templates
from pyhausbus.IBusDataListener import IBusDataListener
from pyhausbus.de.hausbus.homeassistant.proxy.Controller import Controller
from pyhausbus.de.hausbus.homeassistant.proxy.controller.params.EIndex import EIndex
from pyhausbus.de.hausbus.homeassistant.proxy.controller.data.RemoteObjects import (
    RemoteObjects,
)
from pyhausbus.HausBusUtils import LOGGER
import pyhausbus.de.hausbus.homeassistant.proxy.ProxyFactory as ProxyFactory
import pyhausbus.HausBusUtils as HausBusUtils
from pyhausbus.de.hausbus.homeassistant.proxy.controller.data.ModuleId import ModuleId
from pyhausbus.de.hausbus.homeassistant.proxy.controller.data.Configuration import Configuration
import importlib
import traceback
import time
import threading
from pyhausbus.de.hausbus.homeassistant.proxy.controller.data.EvStarted import EvStarted
from pyhausbus.ResultWorker import ResultWorker

class HomeServer(IBusDataListener):
    _instance = None
    bushandler = None

    def __new__(cls, *args, **kwargs):
        if not cls._instance:
            cls._instance = super().__new__(cls, *args, **kwargs)
        return cls._instance

    def __init__(self):
        LOGGER.debug("init homeserver")
        self.bushandler = BusHandler.getInstance()
        self.bushandler.addBusEventListener(ResultWorker())
        self.bushandler.addBusEventListener(self)

    def searchDevices(self):
        controler = Controller(0)
        controler.getModuleId(EIndex.RUNNING)

    def addBusEventListener(self, listener: IBusDataListener):
        self.bushandler.addBusEventListener(listener)

    def removeBusEventListener(self, listener: IBusDataListener):
        self.bushandler.removeBusEventListener(listener)

    def getDeviceInstances(self, senderObjectId: int, remoteObjects: RemoteObjects):
        deviceId = HausBusUtils.getDeviceId(senderObjectId)
        objectList = remoteObjects.getObjectList()

        result = []
        for i in range(0, len(objectList), 2):
            instanceId = objectList[i]
            classId = objectList[i + 1]
            className = ProxyFactory.getBusClassNameForClass(classId)
            objectId = HausBusUtils.getObjectId(deviceId, classId, instanceId)
            
            try:
                module_name, class_name = className.rsplit(".", 1)
                module = importlib.import_module(className)
                cls = getattr(module, class_name)
                obj = cls(objectId)
                result.append(obj)
            except Exception as err:
                LOGGER.error(err,exc_info=True, stack_info=True)
        return result

    def busDataReceived(self, busDataMessage):
        """if a device restarts during runtime, we automatically read moduleId"""
        if isinstance(busDataMessage.getData(), ModuleId):
            Controller(busDataMessage.getSenderObjectId()).getConfiguration()

        if isinstance(busDataMessage.getData(), Configuration):
            Controller(busDataMessage.getSenderObjectId()).getRemoteObjects()

        """ if a device restarts during runtime, we automatically read moduleId"""
        if isinstance(busDataMessage.getData(), EvStarted):
            Controller(busDataMessage.getSenderObjectId()).getModuleId(EIndex.RUNNING)



from pyhausbus.HausBusCommand import HausBusCommand
from pyhausbus.ABusFeature import *
from pyhausbus.ResultWorker import ResultWorker
import pyhausbus.HausBusUtils as HausBusUtils
from pyhausbus.de.hausbus.homeassistant.proxy.rGBDimmer.data.Configuration import Configuration
from pyhausbus.de.hausbus.homeassistant.proxy.rGBDimmer.data.Status import Status

class RGBDimmer(ABusFeature):
  CLASS_ID:int = 22

  def __init__ (self,objectId:int):
    super().__init__(objectId)

  @staticmethod
  def create(deviceId:int, instanceId:int):
    return RGBDimmer(HausBusUtils.getObjectId(deviceId, 22, instanceId))

  """
  """
  def evOff(self):
    LOGGER.debug("evOff")
    hbCommand = HausBusCommand(self.objectId, 200, "evOff")
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param brightnessRed Helligkeit ROT-Anteil. \r\n0: AUS\r\n100: MAX.
  @param brightnessGreen Helligkeit GRUEN-Anteil. \r\n0: AUS\r\n100: MAX.
  @param brightnessBlue Helligkeit BLAU-Anteil. \r\n0: AUS\r\n100: MAX.
  @param duration Einschaltdauer in Sekunden.
  """
  def evOn(self, brightnessRed:int, brightnessGreen:int, brightnessBlue:int, duration:int):
    LOGGER.debug("evOn"+" brightnessRed = "+str(brightnessRed)+" brightnessGreen = "+str(brightnessGreen)+" brightnessBlue = "+str(brightnessBlue)+" duration = "+str(duration))
    hbCommand = HausBusCommand(self.objectId, 201, "evOn")
    hbCommand.addByte(brightnessRed)
    hbCommand.addByte(brightnessGreen)
    hbCommand.addByte(brightnessBlue)
    hbCommand.addWord(duration)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param brightnessRed Helligkeit ROT-Anteil. \r\n0: AUS\r\n100: MAX.
  @param brightnessGreen Helligkeit GRUEN-Anteil. \r\n0: AUS\r\n100: MAX.
  @param brightnessBlue Helligkeit BLAU-Anteil. \r\n0: AUS\r\n100: MAX.
  @param duration Einschaltdauer in Sekunden.
  """
  def setColor(self, brightnessRed:int, brightnessGreen:int, brightnessBlue:int, duration:int):
    LOGGER.debug("setColor"+" brightnessRed = "+str(brightnessRed)+" brightnessGreen = "+str(brightnessGreen)+" brightnessBlue = "+str(brightnessBlue)+" duration = "+str(duration))
    hbCommand = HausBusCommand(self.objectId, 2, "setColor")
    hbCommand.addByte(brightnessRed)
    hbCommand.addByte(brightnessGreen)
    hbCommand.addByte(brightnessBlue)
    hbCommand.addWord(duration)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def getConfiguration(self):
    LOGGER.debug("getConfiguration")
    hbCommand = HausBusCommand(self.objectId, 0, "getConfiguration")
    ResultWorker()._setResultInfo(Configuration,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param fadingTime Zeit a 50ms um 0-100% zu dimmen.
  """
  def setConfiguration(self, fadingTime:int):
    LOGGER.debug("setConfiguration"+" fadingTime = "+str(fadingTime))
    hbCommand = HausBusCommand(self.objectId, 1, "setConfiguration")
    hbCommand.addByte(fadingTime)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  """
  def getStatus(self):
    LOGGER.debug("getStatus")
    hbCommand = HausBusCommand(self.objectId, 5, "getStatus")
    ResultWorker()._setResultInfo(Status,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param fadingTime Zeit a 50ms um zwischen den unterschiedlichen Helligkeitsstufen zu schalten.
  """
  def Configuration(self, fadingTime:int):
    LOGGER.debug("Configuration"+" fadingTime = "+str(fadingTime))
    hbCommand = HausBusCommand(self.objectId, 128, "Configuration")
    hbCommand.addByte(fadingTime)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")

  """
  @param brightnessRed Helligkeit ROT-Anteil. \r\n0: AUS\r\n100: MAX.
  @param brightnessGreen Helligkeit GRUEN-Anteil. \r\n0: AUS\r\n100: MAX.
  @param brightnessBlue Helligkeit BLAU-Anteil. \r\n0: AUS\r\n100: MAX.
  @param duration Einschaltdauer in Sekunden.
  """
  def Status(self, brightnessRed:int, brightnessGreen:int, brightnessBlue:int, duration:int):
    LOGGER.debug("Status"+" brightnessRed = "+str(brightnessRed)+" brightnessGreen = "+str(brightnessGreen)+" brightnessBlue = "+str(brightnessBlue)+" duration = "+str(duration))
    hbCommand = HausBusCommand(self.objectId, 129, "Status")
    hbCommand.addByte(brightnessRed)
    hbCommand.addByte(brightnessGreen)
    hbCommand.addByte(brightnessBlue)
    hbCommand.addWord(duration)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()
    LOGGER.debug("returns")





import pyhausbus.HausBusUtils as HausBusUtils
class MEventMask:

  def setNotifyOnCovered(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 0, self.value)
    return self;

  def isNotifyOnCovered(self):
    return HausBusUtils.isBitSet(0, self.value)
  def setNotifyOnClicked(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 1, self.value)
    return self;

  def isNotifyOnClicked(self):
    return HausBusUtils.isBitSet(1, self.value)
  def setNotifyOnDoubleClicked(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 2, self.value)
    return self;

  def isNotifyOnDoubleClicked(self):
    return HausBusUtils.isBitSet(2, self.value)
  def setNotifyOnStartHold(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 3, self.value)
    return self;

  def isNotifyOnStartHold(self):
    return HausBusUtils.isBitSet(3, self.value)
  def setNotifyOnEndHold(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 4, self.value)
    return self;

  def isNotifyOnEndHold(self):
    return HausBusUtils.isBitSet(4, self.value)
  def setNotifyOnFree(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 5, self.value)
    return self;

  def isNotifyOnFree(self):
    return HausBusUtils.isBitSet(5, self.value)
  def setReserved1(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 6, self.value)
    return self;

  def isReserved1(self):
    return HausBusUtils.isBitSet(6, self.value)
  def setEnableFeedBack(self, setValue:bool):
    self.value = HausBusUtils.setBit(setValue, 7, self.value)
    return self;

  def isEnableFeedBack(self):
    return HausBusUtils.isBitSet(7, self.value)
  def __init__(self, value:int):
    self.value = value

  @staticmethod
  def _fromBytes(data:bytearray, offset):
    return MEventMask(HausBusUtils.bytesToInt(data, offset))



  def getValue(self):
    return self.value
  def getEntryNames(self):
    result = []
    result.append("NotifyOnCovered")
    result.append("NotifyOnClicked")
    result.append("NotifyOnDoubleClicked")
    result.append("NotifyOnStartHold")
    result.append("NotifyOnEndHold")
    result.append("NotifyOnFree")
    result.append("Reserved1")
    result.append("EnableFeedBack")
    return result
  def setEntry(self,name:str, setValue:bool):
    if (name == "NotifyOnCovered"):
      self.setNotifyOnCovered(setValue)
    if (name == "NotifyOnClicked"):
      self.setNotifyOnClicked(setValue)
    if (name == "NotifyOnDoubleClicked"):
      self.setNotifyOnDoubleClicked(setValue)
    if (name == "NotifyOnStartHold"):
      self.setNotifyOnStartHold(setValue)
    if (name == "NotifyOnEndHold"):
      self.setNotifyOnEndHold(setValue)
    if (name == "NotifyOnFree"):
      self.setNotifyOnFree(setValue)
    if (name == "Reserved1"):
      self.setReserved1(setValue)
    if (name == "EnableFeedBack"):
      self.setEnableFeedBack(setValue)

  def __str__(self):
    return f"MEventMask(NotifyOnCovered = {self.isNotifyOnCovered()}, NotifyOnClicked = {self.isNotifyOnClicked()}, NotifyOnDoubleClicked = {self.isNotifyOnDoubleClicked()}, NotifyOnStartHold = {self.isNotifyOnStartHold()}, NotifyOnEndHold = {self.isNotifyOnEndHold()}, NotifyOnFree = {self.isNotifyOnFree()}, Reserved1 = {self.isReserved1()}, EnableFeedBack = {self.isEnableFeedBack()})"






import pyhausbus.HausBusUtils as HausBusUtils

class GetSignalCount:
  CLASS_ID = 90
  FUNCTION_ID = 6

  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return GetSignalCount()

  def __str__(self):
    return f"GetSignalCount()"






from pyhausbus.de.hausbus.homeassistant.proxy.dimmer.params.EMode import EMode
import pyhausbus.HausBusUtils as HausBusUtils

class Configuration:
  CLASS_ID = 17
  FUNCTION_ID = 128

  def __init__(self,mode:EMode, fadingTime:int, dimmingTime:int, dimmingRangeStart:int, dimmingRangeEnd:int):
    self.mode=mode
    self.fadingTime=fadingTime
    self.dimmingTime=dimmingTime
    self.dimmingRangeStart=dimmingRangeStart
    self.dimmingRangeEnd=dimmingRangeEnd


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return Configuration(EMode._fromBytes(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"Configuration(mode={self.mode}, fadingTime={self.fadingTime}, dimmingTime={self.dimmingTime}, dimmingRangeStart={self.dimmingRangeStart}, dimmingRangeEnd={self.dimmingRangeEnd})"

  '''
  @param mode DIMM_CR: Dimmer arbeitet mit Phasenabschnitt\r\nDIMM_L: Dimmer arbeitet mit Phasenanschnitt\r\nSWITCH: Dimmer schaltet nur keine Dimmfunktion\r\n\r\nACHTUNG: EIN FALSCHER MODE.
  '''
  def getMode(self):
    return self.mode

  '''
  @param fadingTime Zeit a 50ms um zwischen den unterschiedlichen Helligkeitsstufen zu schalten.
  '''
  def getFadingTime(self):
    return self.fadingTime

  '''
  @param dimmingTime Zeit a 50ms um zwischen den unterschiedlichen Helligkeitsstufen zu dimmen.
  '''
  def getDimmingTime(self):
    return self.dimmingTime

  '''
  @param dimmingRangeStart Startwert des Helligkeitbereiches in dem gedimmt werden soll. 0-100%.
  '''
  def getDimmingRangeStart(self):
    return self.dimmingRangeStart

  '''
  @param dimmingRangeEnd Endwert des Helligkeitbereiches in dem gedimmt werden soll. 0-100%.
  '''
  def getDimmingRangeEnd(self):
    return self.dimmingRangeEnd






from pyhausbus.de.hausbus.homeassistant.proxy.rFIDReader.params.EState import EState
import pyhausbus.HausBusUtils as HausBusUtils

class State:
  CLASS_ID = 43
  FUNCTION_ID = 129

  def __init__(self,state:EState):
    self.state=state


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return State(EState._fromBytes(dataIn, offset))

  def __str__(self):
    return f"State(state={self.state})"

  '''
  @param state State of the RFID-Reader hardware.
  '''
  def getState(self):
    return self.state






import pyhausbus.HausBusUtils as HausBusUtils

class SetUnitGroupState:
  CLASS_ID = 0
  FUNCTION_ID = 14

  def __init__(self,index:int, member:int, state:int, triggerBits:int):
    self.index=index
    self.member=member
    self.state=state
    self.triggerBits=triggerBits


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return SetUnitGroupState(HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset))

  def __str__(self):
    return f"SetUnitGroupState(index={self.index}, member={self.member}, state={self.state}, triggerBits={self.triggerBits})"

  '''
  @param index Gruppenindex.
  '''
  def getIndex(self):
    return self.index

  '''
  @param member Gruppenteilnehmer 0-15.
  '''
  def getMember(self):
    return self.member

  '''
  @param state Zustand des Teilnehmers 0=AUS.
  '''
  def getState(self):
    return self.state

  '''
  @param triggerBits Anzahl der Teilnehmer die gesetzt sein muessen damit evGroupOn erzeugt wird.
  '''
  def getTriggerBits(self):
    return self.triggerBits






import pyhausbus.HausBusUtils as HausBusUtils

class EvLowPower:
  CLASS_ID = 41
  FUNCTION_ID = 200

  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EvLowPower()

  def __str__(self):
    return f"EvLowPower()"






import pyhausbus.HausBusUtils as HausBusUtils

class AllOn:
  CLASS_ID = 160
  FUNCTION_ID = 3

  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return AllOn()

  def __str__(self):
    return f"AllOn()"



